{% extends 'layout.html' %}

{% block content %}
<article class="article">
    <h2 class="center title">{{ page.title }}</h2>
    <aside>
        <time class="center">{{ page.description }}</time>
    </aside>
    <article class="content">
    {{ page.content }}
    </article>
    <p class="date">Last updata {{ page.date }}</p>
</article>
{% endblock %}
